==> jc-1.4.0.tar.gz: java__5fcup/production__5fpart.h <==
// public abstract class java_cup.production_part

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 548cfcde5f67241c java__5fcup_production__5fpart

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java__5fcup_production__5fpart_H_
#define _JC_java__5fcup_production__5fpart_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java__5fcup_production__5fpart$object;

// Typedefs
typedef struct _jc_java__5fcup_production__5fpart$sub_refs	_jc_java__5fcup_production__5fpart$sub_refs;
typedef struct _jc_java__5fcup_production__5fpart$sub_nonrefs	_jc_java__5fcup_production__5fpart$sub_nonrefs;
typedef struct _jc_java__5fcup_production__5fpart$refs	_jc_java__5fcup_production__5fpart$refs;
typedef struct _jc_java__5fcup_production__5fpart$nonrefs	_jc_java__5fcup_production__5fpart$nonrefs;
typedef struct _jc_java__5fcup_production__5fpart$object	_jc_java__5fcup_production__5fpart$object;

typedef const struct _jc_java__5fcup_production__5fpart$vmethods	_jc_java__5fcup_production__5fpart$vmethods;
typedef const struct _jc_java__5fcup_production__5fpart$vtable	_jc_java__5fcup_production__5fpart$vtable;
typedef const struct _jc_java__5fcup_production__5fpart$vtype	_jc_java__5fcup_production__5fpart$vtype;

// Constructors
extern void _jc_java__5fcup_production__5fpart$method$_init$c31b894660454d13(_jc_env *, struct _jc_java__5fcup_production__5fpart$object *, struct _jc_java_lang_String$object *);

// Virtual methods
extern jboolean _jc_java__5fcup_production__5fpart$method$equals$8a15e0625571c581(_jc_env *, struct _jc_java__5fcup_production__5fpart$object *, struct _jc_java_lang_Object$object *);
extern jboolean _jc_java__5fcup_production__5fpart$method$equals$be62e779d7a4cad7(_jc_env *, struct _jc_java__5fcup_production__5fpart$object *, struct _jc_java__5fcup_production__5fpart$object *);
extern jint _jc_java__5fcup_production__5fpart$method$hashCode$53152098849316df(_jc_env *, struct _jc_java__5fcup_production__5fpart$object *);
extern jboolean _jc_java__5fcup_production__5fpart$method$is__5faction$fd28f66d2d0756ae(_jc_env *, struct _jc_java__5fcup_production__5fpart$object *);
extern struct _jc_java_lang_String$object *_jc_java__5fcup_production__5fpart$method$label$9cad0bca151a9b24(_jc_env *, struct _jc_java__5fcup_production__5fpart$object *);
extern struct _jc_java_lang_String$object *_jc_java__5fcup_production__5fpart$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_java__5fcup_production__5fpart$object *);

// Virtual method descriptors
extern _jc_method _jc_java__5fcup_production__5fpart$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_java__5fcup_production__5fpart$method_info$equals$be62e779d7a4cad7;
extern _jc_method _jc_java__5fcup_production__5fpart$method_info$hashCode$53152098849316df;
extern _jc_method _jc_java__5fcup_production__5fpart$method_info$is__5faction$fd28f66d2d0756ae;
extern _jc_method _jc_java__5fcup_production__5fpart$method_info$label$9cad0bca151a9b24;
extern _jc_method _jc_java__5fcup_production__5fpart$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_java__5fcup_production__5fpart$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_java__5fcup_production__5fpart$object *, struct _jc_java_lang_Object$object *);
	jboolean	(*equals$be62e779d7a4cad7)(_jc_env *, struct _jc_java__5fcup_production__5fpart$object *, struct _jc_java__5fcup_production__5fpart$object *);
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_java__5fcup_production__5fpart$object *);
	jboolean	(*is__5faction$fd28f66d2d0756ae)(_jc_env *, struct _jc_java__5fcup_production__5fpart$object *);
	struct _jc_java_lang_String$object	*(*label$9cad0bca151a9b24)(_jc_env *, struct _jc_java__5fcup_production__5fpart$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_java__5fcup_production__5fpart$object *);
};

// Vtable
struct _jc_java__5fcup_production__5fpart$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java__5fcup_production__5fpart$vmethods	java__5fcup_production__5fpart;
};

// Vtype
struct _jc_java__5fcup_production__5fpart$vtype {
	_jc_type			type;
	_jc_java__5fcup_production__5fpart$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java__5fcup_production__5fpart$sub_refs {
	struct _jc_java_lang_String$object	*__5flabel;
};

// Reference instance fields (object)
struct _jc_java__5fcup_production__5fpart$refs {
    _jc_java__5fcup_production__5fpart$sub_refs	java__5fcup_production__5fpart;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java__5fcup_production__5fpart$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java__5fcup_production__5fpart$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java__5fcup_production__5fpart$sub_nonrefs	java__5fcup_production__5fpart;
};

// Object instance structure
struct _jc_java__5fcup_production__5fpart$object {
	_jc_java__5fcup_production__5fpart$refs	refs[0];
	_jc_word		lockword;
	_jc_java__5fcup_production__5fpart$vtype	*vtype;
	_jc_java__5fcup_production__5fpart$nonrefs	nonrefs;
};

// Type structure
extern _jc_java__5fcup_production__5fpart$vtype _jc_java__5fcup_production__5fpart$type;

// Array types class info structures
_JC_DECL_ARRAYS(java__5fcup_production__5fpart, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java__5fcup_production__5fpart$class_object;

#endif	/* _JC_java__5fcup_production__5fpart_H_ */

==> jc-1.4.6.tar.gz: java__5fcup/production__5fpart.h <==
// public abstract class java_cup.production_part

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 548cfcde5f67241c java__5fcup_production__5fpart

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java__5fcup_production__5fpart_H_
#define _JC_java__5fcup_production__5fpart_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java__5fcup_production__5fpart$object;

// Typedefs
typedef struct _jc_java__5fcup_production__5fpart$sub_refs	_jc_java__5fcup_production__5fpart$sub_refs;
typedef struct _jc_java__5fcup_production__5fpart$sub_nonrefs	_jc_java__5fcup_production__5fpart$sub_nonrefs;
typedef struct _jc_java__5fcup_production__5fpart$refs	_jc_java__5fcup_production__5fpart$refs;
typedef struct _jc_java__5fcup_production__5fpart$nonrefs	_jc_java__5fcup_production__5fpart$nonrefs;
typedef struct _jc_java__5fcup_production__5fpart$object	_jc_java__5fcup_production__5fpart$object;

typedef const struct _jc_java__5fcup_production__5fpart$vmethods	_jc_java__5fcup_production__5fpart$vmethods;
typedef const struct _jc_java__5fcup_production__5fpart$vtable	_jc_java__5fcup_production__5fpart$vtable;
typedef const struct _jc_java__5fcup_production__5fpart$vtype	_jc_java__5fcup_production__5fpart$vtype;

// Constructors
extern void _jc_java__5fcup_production__5fpart$method$_init$c31b894660454d13(_jc_env *, struct _jc_java__5fcup_production__5fpart$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_java__5fcup_production__5fpart$method$equals$8a15e0625571c581(_jc_env *, struct _jc_java__5fcup_production__5fpart$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern jboolean _jc_java__5fcup_production__5fpart$method$equals$be62e779d7a4cad7(_jc_env *, struct _jc_java__5fcup_production__5fpart$object *, struct _jc_java__5fcup_production__5fpart$object *) _JC_JCNI_ATTR;
extern jint _jc_java__5fcup_production__5fpart$method$hashCode$53152098849316df(_jc_env *, struct _jc_java__5fcup_production__5fpart$object *) _JC_JCNI_ATTR;
extern jboolean _jc_java__5fcup_production__5fpart$method$is__5faction$fd28f66d2d0756ae(_jc_env *, struct _jc_java__5fcup_production__5fpart$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_java__5fcup_production__5fpart$method$label$9cad0bca151a9b24(_jc_env *, struct _jc_java__5fcup_production__5fpart$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_java__5fcup_production__5fpart$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_java__5fcup_production__5fpart$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java__5fcup_production__5fpart$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_java__5fcup_production__5fpart$method_info$equals$be62e779d7a4cad7;
extern _jc_method _jc_java__5fcup_production__5fpart$method_info$hashCode$53152098849316df;
extern _jc_method _jc_java__5fcup_production__5fpart$method_info$is__5faction$fd28f66d2d0756ae;
extern _jc_method _jc_java__5fcup_production__5fpart$method_info$label$9cad0bca151a9b24;
extern _jc_method _jc_java__5fcup_production__5fpart$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_java__5fcup_production__5fpart$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_java__5fcup_production__5fpart$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	jboolean	(*equals$be62e779d7a4cad7)(_jc_env *, struct _jc_java__5fcup_production__5fpart$object *, struct _jc_java__5fcup_production__5fpart$object *) _JC_JCNI_ATTR;
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_java__5fcup_production__5fpart$object *) _JC_JCNI_ATTR;
	jboolean	(*is__5faction$fd28f66d2d0756ae)(_jc_env *, struct _jc_java__5fcup_production__5fpart$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*label$9cad0bca151a9b24)(_jc_env *, struct _jc_java__5fcup_production__5fpart$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_java__5fcup_production__5fpart$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java__5fcup_production__5fpart$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java__5fcup_production__5fpart$vmethods	java__5fcup_production__5fpart;
};

// Vtype
struct _jc_java__5fcup_production__5fpart$vtype {
	_jc_type			type;
	_jc_java__5fcup_production__5fpart$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java__5fcup_production__5fpart$sub_refs {
	struct _jc_java_lang_String$object	*__5flabel;
};

// Reference instance fields (object)
struct _jc_java__5fcup_production__5fpart$refs {
    _jc_java__5fcup_production__5fpart$sub_refs	java__5fcup_production__5fpart;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java__5fcup_production__5fpart$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java__5fcup_production__5fpart$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java__5fcup_production__5fpart$sub_nonrefs	java__5fcup_production__5fpart;
};

// Object instance structure
struct _jc_java__5fcup_production__5fpart$object {
	_jc_java__5fcup_production__5fpart$refs	refs[0];
	_jc_word		lockword;
	_jc_java__5fcup_production__5fpart$vtype	*vtype;
	_jc_java__5fcup_production__5fpart$nonrefs	nonrefs;
};

// Type structure
extern _jc_java__5fcup_production__5fpart$vtype _jc_java__5fcup_production__5fpart$type;

// Array types class info structures
_JC_DECL_ARRAYS(java__5fcup_production__5fpart, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java__5fcup_production__5fpart$class_object;

#endif	/* _JC_java__5fcup_production__5fpart_H_ */
